@@ -34,11 +34,11 @@ try:
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.bigquery_data_exchange_v1beta1 import common  # type: ignore
 from google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service import (
     pagers,
 )
 from google.cloud.bigquery_data_exchange_v1beta1.types import dataexchange
+from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
@@ -84,12 +84,13 @@ class AnalyticsHubServiceClientMeta(type):
 
 
 class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
-    """The AnalyticsHubService API facilitates data sharing within
-    and across organizations. It allows data providers to publish
-    Listings --- a discoverable and searchable SKU representing a
-    dataset. Data consumers can subscribe to Listings. Upon
-    subscription, AnalyticsHub provisions a "Linked Datasets"
-    surfacing the data in the consumer's project.
+    """The ``AnalyticsHubService`` API facilitates data sharing within and
+    across organizations. It allows data providers to publish listings
+    that reference shared datasets. With Analytics Hub, users can
+    discover and search for listings that they have access to.
+    Subscribers can view and subscribe to listings. When you subscribe
+    to a listing, Analytics Hub creates a linked dataset in your
+    project.
     """
 
     @staticmethod
@@ -489,7 +490,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataExchangesPager:
-        r"""Lists DataExchanges in a given project and location.
+        r"""Lists all data exchanges in a given project and
+        location.
 
         .. code-block:: python
 
@@ -513,11 +515,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListDataExchangesRequest, dict]):
-                The request object. Message for requesting list of
-                DataExchanges.
+                The request object. Message for requesting the list of
+                data exchanges.
             parent (str):
-                Required. The parent resource path of the DataExchanges.
-                e.g. ``projects/myproject/locations/US``.
+                Required. The parent resource path of the data
+                exchanges. e.g. ``projects/myproject/locations/US``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -530,8 +532,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service.pagers.ListDataExchangesPager:
-                Message for response to listing
-                DataExchanges.
+                Message for response to the list of
+                data exchanges.
                 Iterating over this object will yield
                 results and resolve additional pages
                 automatically.
@@ -597,7 +599,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOrgDataExchangesPager:
-        r"""Lists DataExchanges from projects in a given
+        r"""Lists all data exchanges from projects in a given
         organization and location.
 
         .. code-block:: python
@@ -622,8 +624,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListOrgDataExchangesRequest, dict]):
-                The request object. Message for requesting list of
-                DataExchanges from projects in an organization and
+                The request object. Message for requesting the list of
+                data exchanges from projects in an organization and
                 location.
             organization (str):
                 Required. The organization resource path of the projects
@@ -641,8 +643,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service.pagers.ListOrgDataExchangesPager:
-                Message for response to listing
-                DataExchanges in an organization and
+                Message for response to listing data
+                exchanges in an organization and
                 location.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -711,7 +713,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
-        r"""Gets details of a single DataExchange.
+        r"""Gets the details of a data exchange.
 
         .. code-block:: python
 
@@ -734,9 +736,9 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.GetDataExchangeRequest, dict]):
-                The request object. Message for getting a DataExchange.
+                The request object. Message for getting a data exchange.
             name (str):
-                Required. The resource name of the DataExchange. e.g.
+                Required. The resource name of the data exchange. e.g.
                 ``projects/myproject/locations/US/dataExchanges/123``.
 
                 This corresponds to the ``name`` field
@@ -751,10 +753,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange:
                 A data exchange is a container that
-                enables data sharing. It contains a set
-                of listings of the data sources along
-                with descriptive information of the data
-                exchange.
+                lets you share data. Along with the
+                descriptive information about the data
+                exchange, it contains listings that
+                reference shared datasets.
 
         """
         # Create or coerce a protobuf request object.
@@ -809,8 +811,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
-        r"""Creates a new DataExchange in a given project and
-        location.
+        r"""Creates a new data exchange.
 
         .. code-block:: python
 
@@ -838,16 +839,19 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateDataExchangeRequest, dict]):
-                The request object. Message for creating a DataExchange.
+                The request object. Message for creating a data
+                exchange.
             parent (str):
-                Required. The parent resource path of the DataExchange.
+                Required. The parent resource path of the data exchange.
                 e.g. ``projects/myproject/locations/US``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             data_exchange (google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange):
-                Required. The DataExchange to create.
+                Required. The data exchange to
+                create.
+
                 This corresponds to the ``data_exchange`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -860,10 +864,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange:
                 A data exchange is a container that
-                enables data sharing. It contains a set
-                of listings of the data sources along
-                with descriptive information of the data
-                exchange.
+                lets you share data. Along with the
+                descriptive information about the data
+                exchange, it contains listings that
+                reference shared datasets.
 
         """
         # Create or coerce a protobuf request object.
@@ -920,7 +924,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.DataExchange:
-        r"""Updates the parameters of a single DataExchange.
+        r"""Updates an existing data exchange.
 
         .. code-block:: python
 
@@ -946,17 +950,20 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.UpdateDataExchangeRequest, dict]):
-                The request object. Message for updating a DataExchange.
+                The request object. Message for updating a data
+                exchange.
             data_exchange (google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange):
-                Required. The DataExchange to update.
+                Required. The data exchange to
+                update.
+
                 This corresponds to the ``data_exchange`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             update_mask (google.protobuf.field_mask_pb2.FieldMask):
-                Required. Field mask is used to specify the fields to be
-                overwritten in the DataExchange resource by the update.
-                The fields specified in the update_mask are relative to
-                the resource, not the full request.
+                Required. Field mask specifies the fields to update in
+                the data exchange resource. The fields specified in the
+                ``updateMask`` are relative to the resource and are not
+                a full request.
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -970,10 +977,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.types.DataExchange:
                 A data exchange is a container that
-                enables data sharing. It contains a set
-                of listings of the data sources along
-                with descriptive information of the data
-                exchange.
+                lets you share data. Along with the
+                descriptive information about the data
+                exchange, it contains listings that
+                reference shared datasets.
 
         """
         # Create or coerce a protobuf request object.
@@ -1031,7 +1038,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
-        r"""Deletes a single DataExchange.
+        r"""Deletes an existing data exchange.
 
         .. code-block:: python
 
@@ -1051,10 +1058,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteDataExchangeRequest, dict]):
-                The request object. Message for deleting a DataExchange.
+                The request object. Message for deleting a data
+                exchange.
             name (str):
-                Required. Resource name of the DataExchange to delete.
-                e.g.
+                Required. The full name of the data exchange resource
+                that you want to delete. For example,
                 ``projects/myproject/locations/US/dataExchanges/123``.
 
                 This corresponds to the ``name`` field
@@ -1114,7 +1122,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListListingsPager:
-        r"""Lists Listings in a given project and location.
+        r"""Lists all listings in a given project and location.
 
         .. code-block:: python
 
@@ -1138,8 +1146,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.ListListingsRequest, dict]):
-                The request object. Message for requesting list of
-                Listings.
+                The request object. Message for requesting the list of
+                listings.
             parent (str):
                 Required. The parent resource path of the listing. e.g.
                 ``projects/myproject/locations/US/dataExchanges/123``.
@@ -1155,7 +1163,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.services.analytics_hub_service.pagers.ListListingsPager:
-                Message for response to listing
+                Message for response to the list of
                 Listings.
                 Iterating over this object will yield
                 results and resolve additional pages
@@ -1222,7 +1230,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
-        r"""Gets details of a single Listing.
+        r"""Gets the details of a listing.
 
         .. code-block:: python
 
@@ -1245,7 +1253,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.GetListingRequest, dict]):
-                The request object. Message for getting a Listing.
+                The request object. Message for getting a listing.
             name (str):
                 Required. The resource name of the listing. e.g.
                 ``projects/myproject/locations/US/dataExchanges/123/listings/456``.
@@ -1321,8 +1329,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
-        r"""Creates a new Listing in a given project and
-        location.
+        r"""Creates a new listing.
 
         .. code-block:: python
 
@@ -1350,7 +1357,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.CreateListingRequest, dict]):
-                The request object. Message for creating a Listing.
+                The request object. Message for creating a listing.
             parent (str):
                 Required. The parent resource path of the listing. e.g.
                 ``projects/myproject/locations/US/dataExchanges/123``.
@@ -1433,7 +1440,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.Listing:
-        r"""Updates the parameters of a single Listing.
+        r"""Updates an existing listing.
 
         .. code-block:: python
 
@@ -1466,10 +1473,10 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             update_mask (google.protobuf.field_mask_pb2.FieldMask):
-                Required. Field mask is used to specify the fields to be
-                overwritten in the Listing resource by the update. The
-                fields specified in the update_mask are relative to the
-                resource, not the full request.
+                Required. Field mask specifies the fields to update in
+                the listing resource. The fields specified in the
+                ``updateMask`` are relative to the resource and are not
+                a full request.
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1545,9 +1552,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
-        r"""Deletes a single Listing, as long as there are no
-        subscriptions associated with the source of this
-        Listing.
+        r"""Deletes a listing.
 
         .. code-block:: python
 
@@ -1567,7 +1572,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.DeleteListingRequest, dict]):
-                The request object. Message for deleting a Listing.
+                The request object. Message for deleting a listing.
             name (str):
                 Required. Resource name of the listing to delete. e.g.
                 ``projects/myproject/locations/US/dataExchanges/123/listings/456``.
@@ -1629,11 +1634,12 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> dataexchange.SubscribeListingResponse:
-        r"""Subscribes to a single Listing.
-        Data Exchange currently supports one type of Listing: a
-        BigQuery dataset. Upon subscription to a Listing for a
-        BigQuery dataset, Data Exchange creates a linked dataset
-        in the subscriber's project.
+        r"""Subscribes to a listing.
+        Currently, with Analytics Hub, you can create listings
+        that reference only BigQuery datasets.
+        Upon subscription to a listing for a BigQuery dataset,
+        Analytics Hub creates a linked dataset in the
+        subscriber's project.
 
         .. code-block:: python
 
@@ -1662,10 +1668,11 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Args:
             request (Union[google.cloud.bigquery_data_exchange_v1beta1.types.SubscribeListingRequest, dict]):
-                The request object. Message for subscribing a Listing.
+                The request object. Message for subscribing to a
+                listing.
             name (str):
-                Required. Resource name of the listing to subscribe to.
-                e.g.
+                Required. Resource name of the listing that you want to
+                subscribe to. e.g.
                 ``projects/myproject/locations/US/dataExchanges/123/listings/456``.
 
                 This corresponds to the ``name`` field
@@ -1679,8 +1686,8 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
 
         Returns:
             google.cloud.bigquery_data_exchange_v1beta1.types.SubscribeListingResponse:
-                Message for response to subscribing a
-                Listing. Empty for now.
+                Message for response when you
+                subscribe to a listing.
 
         """
         # Create or coerce a protobuf request object.
@@ -1733,7 +1740,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
-        r"""Gets the IAM policy for a dataExchange or a listing.
+        r"""Gets the IAM policy.
 
         .. code-block:: python
 
@@ -1868,7 +1875,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
-        r"""Sets the IAM policy for a dataExchange or a listing.
+        r"""Sets the IAM policy.
 
         .. code-block:: python
 
@@ -2003,8 +2010,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
-        r"""Returns the permissions that a caller has on a
-        specified dataExchange or listing.
+        r"""Returns the permissions that a caller has.
 
         .. code-block:: python
 
@@ -2084,6 +2090,114 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         """
         self.transport.close()
 
+    def get_location(
+        self,
+        request: locations_pb2.GetLocationRequest = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> locations_pb2.Location:
+        r"""Gets information about a location.
+
+        Args:
+            request (:class:`~.location_pb2.GetLocationRequest`):
+                The request object. Request message for
+                `GetLocation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                 if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.location_pb2.Location:
+                Location object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = locations_pb2.GetLocationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.get_location,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def list_locations(
+        self,
+        request: locations_pb2.ListLocationsRequest = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> locations_pb2.ListLocationsResponse:
+        r"""Lists information about the supported locations for this service.
+
+        Args:
+            request (:class:`~.location_pb2.ListLocationsRequest`):
+                The request object. Request message for
+                `ListLocations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                 if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.location_pb2.ListLocationsResponse:
+                Response message for ``ListLocations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = locations_pb2.ListLocationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.list_locations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
